From 5ac8dabbedc305553151b97bc5b7d60a43b02a64 Mon Sep 17 00:00:00 2001
From: Ben Finney <ben@benfinney.id.au>
Date: Sun, 25 Oct 2015 15:10:14 +1100
Subject: [PATCH 1/2] Add helper function to remove a filesystem entry of any
 type.

---
 dhpython/fs.py | 13 +++++++++++++
 1 file changed, 13 insertions(+)

diff --git a/dhpython/fs.py b/dhpython/fs.py
index e0be654..05b8e8b 100644
--- a/dhpython/fs.py
+++ b/dhpython/fs.py
@@ -25,6 +25,8 @@ from filecmp import cmp as cmpfile
 from os.path import exists, dirname, isdir, islink, join, split, splitext
 from shutil import rmtree
 from stat import ST_MODE, S_IXUSR, S_IXGRP, S_IXOTH
+import errno
+
 from dhpython import MULTIARCH_DIR_TPL
 from dhpython.tools import fix_shebang, clean_egg_name
 from dhpython.interpreter import Interpreter
@@ -32,6 +34,17 @@ from dhpython.interpreter import Interpreter
 log = logging.getLogger('dhpython')
 
 
+def remove_entry(path):
+    """ Remove specified filesystem entry, whatever its type. """
+    try:
+        os.remove(path)
+    except OSError as exc:
+        if exc.errno == errno.EISDIR:
+            os.rmdir(path)
+        else:
+            raise
+
+
 def fix_locations(package, interpreter, versions, options):
     """Move files to the right location."""
     # make a copy since we change version later
-- 
2.6.1

